@@ -40,16 +40,14 @@ def raise_exception(error):
     try:
         if isinstance(error, str):
             raise DevoClientException(proc_json()(error))
-        elif isinstance(error, DevoClientException):
+        if isinstance(error, DevoClientException):
             if isinstance(error.args[0], str):
                 raise DevoClientException(proc_json()(error.args[0]))
-            else:
-                raise DevoClientException(error.args[0])
-        elif isinstance(error, dict):
+            raise DevoClientException(error.args[0])
+        if isinstance(error, dict):
             raise DevoClientException(error)
-        else:
-            response_text = proc_json()(error.text)
-            raise DevoClientException(response_text)
+        response_text = proc_json()(error.text)
+        raise DevoClientException(response_text)
     except json.decoder.JSONDecodeError:
         raise DevoClientException(_format_error(error))
 
@@ -76,8 +74,10 @@ class ClientConfig:
         self.stream = stream
         self.response = response
         self.destination = destination
-        self.proc = processor
-        self.processor = processors()[self.proc]()
+        self.proc = None
+        self.processor = None
+        self.set_processor(processor)
+
         if pragmas:
             self.pragmas = pragmas
             if "user" not in self.pragmas.keys():
@@ -94,9 +94,18 @@ class ClientConfig:
         :param processor: lambda function
         :return:
         """
-        if processor:
+        if isinstance(processor, (str, bytes)):
             self.proc = processor
-            self.processor = processors()[self.proc]()
+            try:
+                self.processor = processors()[self.proc]()
+            except KeyError:
+                raise_exception("Processor not found")
+        elif isinstance(processor, (type(lambda x: 0))):
+            self.proc = "CUSTOM"
+            self.processor = processor
+        else:
+            raise_exception("processor must be lambda/function or one of"
+                            "the defaults API processors.")
         return True
 
     def set_user(self, user=CLIENT_DEFAULT_USER):
@@ -209,7 +218,7 @@ class Client:
         :param dates: object with options for query, see doc
         :return: updated opts
         """
-        default = {'from': 'yesterday()', 'to': None}
+        default = {'from': '1h', 'to': None}
         if not dates:
             return default
 
@@ -376,11 +385,20 @@ class Client:
         :param opts: destination -> Destination for the results
         :return: Return the formed payload
         """
-        payload = {"from": int(default_from(dates['from']) / 1000),
-                   "to": int(default_to(dates['to']) / 1000) if dates['to']
-                         is not None
-                         else None,
-                   "mode": {"type": opts['response']}}
+        date_from = default_from(dates['from'])
+        date_to = default_to(dates['to'])
+        payload = {
+            "from":
+                int(date_from / 1000) if isinstance(date_from, (int, float))
+                else date_from,
+            "to":
+                int(date_to / 1000) if isinstance(date_to, (int, float))
+                else date_to,
+            "mode": {"type": opts['response']}}
+
+        if dates.get("timeZone"):
+            payload['timeZone'] = dates.get("timeZone")
+
         if query:
             payload['query'] = query
 
