@@ -41,7 +41,14 @@ def cli(version):
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
 @click.option('--sec_level', help='Sec level for opensslsocket. Default: None',
-              default=None)
+              type=int)
+@click.option('--verify_mode', help='Verify mode for SSL Socket. '
+                                    'Default: SSL default.'
+                                    'You need use int "0" (CERT_NONE), '
+                                    '"1" (CERT_OPTIONAL) or '
+                                    '"2" (CERT_REQUIRED)', type=int)
+@click.option('--check_hostname', help='Verify cert hostname. Default: True',
+              type=bool)
 @click.option('--multiline/--no-multiline', help='Flag for multiline (With '
                                                  'break-line in msg). '
                                                  'Default False', default=False)
@@ -56,16 +63,31 @@ def cli(version):
               default="")
 @click.option('--header', '-h', help='This option is used to indicate if the'
                                      ' file has headers or not, not to send '
-                                     'them.', default=False)
+                                     'them.', default=False, type=bool)
 @click.option('--raw', is_flag=True, help='Send raw events from a '
                                           'file when using --file')
 @click.option('--debug/--no-debug', help='For testing purposes', default=False)
+@click.option('--zip/--no-zip', help='For testing purposes', default=False,
+              type=bool)
+@click.option('--buffer', help='Buffer size for zipped data.', type=int)
+@click.option('--compression_level', help='Compression level for zipped data. '
+                                          'Read readme for more info',
+              type=int)
+@click.option('--env', '-e', help='Use env vars for configuration',
+              default=False, type=bool)
+@click.option('--default', '-d', help='Use default file for configuration',
+              default=False, type=bool)
 def data(**kwargs):
     """Send data to devo"""
     config = configure(kwargs)
     sended = 0
     try:
         con = Sender(config=config)
+        if config.get("buffer", None) is not None:
+            con.buffer_size(size=config.get("buffer"))
+        if config.get("compression_level", None) is not None:
+            con.compression_level(cl=config.get("compression_level"))
+
         if config['file']:
             if not os.path.isfile(config['file']):
                 print_error(str("File not exist"))
@@ -75,10 +97,12 @@ def data(**kwargs):
                     content = file.read()
                     if not config['raw']:
                         sended += con.send(tag=config['tag'], msg=content,
-                                           multiline=config['multiline'])
+                                           multiline=config['multiline'],
+                                           zip=config.get("zip", False))
                     else:
                         sended += con.send_raw(content,
-                                               multiline=config['multiline'])
+                                               multiline=config['multiline'],
+                                               zip=config.get("zip", False))
             else:
                 with open(config['file']) as file:
                     if config['header']:
@@ -87,9 +111,11 @@ def data(**kwargs):
                         if config['raw']:
                             sended += con.send_raw(line)
                         else:
-                            sended += con.send(tag=config['tag'], msg=line)
+                            sended += con.send(tag=config['tag'], msg=line,
+                                               zip=config.get("zip", False))
         else:
-            sended += con.send(tag=config['tag'], msg=config['line'])
+            sended += con.send(tag=config['tag'], msg=config['line'],
+                               zip=config.get("zip", False))
 
         con.close()
         if config.get("debug", False):
@@ -107,16 +133,23 @@ def data(**kwargs):
 @click.option('--config', '-c', type=click.Path(exists=True),
               help='Optional JSON/Yaml File with configuration info.')
 @click.option('--env', '-e', help='Use env vars for configuration',
-              default=False)
+              default=False, type=bool)
 @click.option('--default', '-d', help='Use default file for configuration',
-              default=False)
+              default=False, type=bool)
 @click.option('--url', '--address', '-a', help='Devo relay address')
 @click.option('--port', '-p', default=443, help='Devo relay address port')
 @click.option('--key', help='Devo user key cert file.')
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
 @click.option('--sec_level', help='Sec level for opensslsocket. Default: None',
-              default=None)
+              type=int)
+@click.option('--verify_mode', help='Verify mode for SSL Socket. '
+                                    'Default: SSL default.'
+                                    'You need use int "0" (CERT_NONE), '
+                                    '"1" (CERT_OPTIONAL) or '
+                                    '"2" (CERT_REQUIRED)', type=int)
+@click.option('--check_hostname', help='Verify cert hostname. Default: True',
+              type=bool)
 @click.option('--type', help='Connection type: SSL or TCP', default="SSL")
 @click.option('--name', '-n', help='Name for Lookup.')
 @click.option('--action', '-ac', help='INC or FULL.', default="FULL")
@@ -139,6 +172,7 @@ def lookup(**kwargs):
     """Send csv lookups to devo"""
     config = configure_lookup(kwargs)
     con = Sender(config=config)
+
     lookup = Lookup(name=config['name'], historic_tag=None, con=con)
 
     # with open(config['file']) as file:
